import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-y5VZBOL8.js";import{a as u,b as d,j as i,u as n,ad as l,ac as m,e as f,aN as _}from"./jwt-decode.esm-BAedLjyW.js";import{u as b}from"./workspaceStore-B06MtSZO.js";import"./CircularLoading-CeZnVq0I.js";import"./Logo-kQcB_c99.js";import"./string-D5NhPnBc.js";import"./index-DET2Pbf7.js";import"./userStore-DY5lKnwS.js";import"./url-CYbRhWDw.js";import"./colorHelpers-sfOurvts.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="799ec9d2-aaae-4110-ba55-07f8a6a950bc",e._sentryDebugIdIdentifier="sentry-dbid-799ec9d2-aaae-4110-ba55-07f8a6a950bc")}catch{}})();const g={class:"runner"},y=u({__name:"Login",setup(e){const a=l(),o=m(),r=b(),c=async()=>{const{redirect:t,...s}=o.query;if(t){await a.push({path:t,query:s,params:o.params});return}a.push({name:"playerHome",query:s})};return(t,s)=>(f(),d("div",g,[i(p,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),E=_(y,[["__scopeId","data-v-12c690e1"]]);export{E as default};
//# sourceMappingURL=Login-Hf92NBXK.js.map
