import{A as n}from"./index-TT2itFIK.js";import{a,c as o,b as r,g as d,E as c,j as l,u as f,e as p,aN as i}from"./jwt-decode.esm-BAedLjyW.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="33a7ded1-8a05-407d-94c4-be86d79d25aa",e._sentryDebugIdIdentifier="sentry-dbid-33a7ded1-8a05-407d-94c4-be86d79d25aa")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(p(),r("nav",{key:0,class:c(["p-steps",{"full-screen":!e.isPreview}])},[l(f(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):d("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-CrDfHatb.js.map
