import{P as _}from"./PlayerNavbar-BDM968mj.js";import{a as f,ac as c,r as h,c as b,b as y,p as k,g as v,h as w,u as n,j as L,a4 as C,ad as N,e as i,aN as I}from"./jwt-decode.esm-BAedLjyW.js";import{u as V}from"./workspaceStore-B06MtSZO.js";import"./userStore-DY5lKnwS.js";import"./metadata-Bo624r0d.js";import"./PhWebhooksLogo.vue-j_n1znP9.js";import"./LoadingOutlined-DFctDkdn.js";import"./PhSignOut.vue-CUWmkJin.js";import"./index-BBYlczbj.js";import"./url-CYbRhWDw.js";import"./colorHelpers-sfOurvts.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="b71195be-d9d8-4a5c-9672-4999416a38ba",a._sentryDebugIdIdentifier="sentry-dbid-b71195be-d9d8-4a5c-9672-4999416a38ba")}catch{}})();const B={class:"main-container"},D={class:"content"},R=f({__name:"Main",setup(a){const e=N(),o=V(),d=c().path,t=h(null),u=async({path:r,id:s})=>{t.value=s,await e.push({path:`/${r}`}),t.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},m=b(()=>!!c().meta.hideLogin);return(r,s)=>{const g=C("RouterView");return i(),y("div",B,[n(o).state.workspace?(i(),k(_,{key:0,"current-path":n(d),"hide-login":m.value,"runner-data":n(o).state.workspace,loading:t.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(g)])])}}}),F=I(R,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main-DG1zcGr-.js.map
