const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-CedzVEsi.js","assets/workspaceStore-B06MtSZO.js","assets/jwt-decode.esm-BAedLjyW.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-DY5lKnwS.js","assets/url-CYbRhWDw.js","assets/colorHelpers-sfOurvts.js","assets/OidcLogoutCallback-ClP7fMmh.js","assets/Login-Hf92NBXK.js","assets/Login.vue_vue_type_script_setup_true_lang-y5VZBOL8.js","assets/CircularLoading-CeZnVq0I.js","assets/CircularLoading-C7OKHy4X.css","assets/Logo-kQcB_c99.js","assets/Logo-D2kepPyK.css","assets/string-D5NhPnBc.js","assets/index-DET2Pbf7.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-DG1zcGr-.js","assets/PlayerNavbar-BDM968mj.js","assets/metadata-Bo624r0d.js","assets/PhWebhooksLogo.vue-j_n1znP9.js","assets/LoadingOutlined-DFctDkdn.js","assets/PhSignOut.vue-CUWmkJin.js","assets/index-BBYlczbj.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-DHj7ziQa.js","assets/Watermark-Cpcdpvc6.js","assets/constants-Dq9beThC.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-CYURH92b.js","assets/index-C0lwIePv.js","assets/Home-B6UGln4L.css","assets/Error-Dem0fhfS.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-D-eW3vYA.js","assets/Error-CIbhyrKS.css","assets/Form-BLC3kS_g.js","assets/FormRunner-BvUjBKte.js","assets/Steps-CrDfHatb.js","assets/index-TT2itFIK.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-B9jkFDTn.js","assets/asyncComputed-C4AsQeL-.js","assets/uuid-CWB2ZOvJ.js","assets/Form-BkLIfVj9.css"])))=>i.map(i=>d[i]);
import{af as c,ag as d,ah as t,ai as m}from"./jwt-decode.esm-BAedLjyW.js";import{a as u}from"./workspaceStore-B06MtSZO.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="f51f163a-52fe-4d09-9db3-23355a5b6ee9",a._sentryDebugIdIdentifier="sentry-dbid-f51f163a-52fe-4d09-9db3-23355a5b6ee9")}catch{}})();const f=async()=>{try{const a=await fetch("/_editor/api/workspace/version");return a.ok&&(await a.json()).version||"7245d8c49e5b14b22d9c60a4857b5844ada7a325"}catch(a){return console.error("Failed to fetch Abstra version:",a),"7245d8c49e5b14b22d9c60a4857b5844ada7a325"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-CedzVEsi.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-ClP7fMmh.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-Hf92NBXK.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-DG1zcGr-.js"),__vite__mapDeps([18,19,4,2,3,1,5,6,20,21,22,23,24,25,26])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-DHj7ziQa.js"),__vite__mapDeps([27,20,2,3,21,28,1,4,5,6,29,30,31,32,22,33])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-Dem0fhfS.js"),__vite__mapDeps([34,35,12,2,3,13,29,1,4,5,6,32,36])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BLC3kS_g.js"),__vite__mapDeps([37,4,2,3,38,9,1,5,6,10,11,12,13,14,15,16,39,40,41,28,29,30,42,43,44,45,46])),meta:{hideLogin:!0}}]}],o=c({history:d("/"),routes:p,scrollBehavior(a){if(a.hash)return{el:a.hash}}}),l=a=>async(e,r)=>{if(m(e,r),e.meta.allowUnauthenticated)return;const n=await u(e.path),{redirect:i,...s}=e.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await a.push({name:"playerLogin",query:{...s,redirect:i||e.path},params:e.params});break;case"NOT_FOUND":await a.push({name:"error",params:{status:"404"}});break;default:await a.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,f as g,o as r};
//# sourceMappingURL=router--iWj-LDW.js.map
