import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-1gKnZXyF.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-BAedLjyW.js";import"./router-Sy-waKYz.js";import"./ts.worker-D3wrISmc.js";import"./fetch-DXPT7C0P.js";import"./record-R7ERdsN8.js";import"./SaveButton-BfRaAUva.js";import"./ExclamationCircleOutlined-D6kFchZM.js";import"./CrudView-DISLIcxw.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DcRCKDj3.js";import"./constants-Dq9beThC.js";import"./url-CYbRhWDw.js";import"./PhDotsThreeVertical.vue-5_pkXY5G.js";import"./index-BKPq_54z.js";import"./asyncComputed-C4AsQeL-.js";import"./omniChatStore-em1M3yQ_.js";import"./uuid-CWB2ZOvJ.js";import"./PhCopySimple.vue-B0wrhOJ7.js";import"./PhPencil.vue-b9lzU7YJ.js";import"./useCodebaseEvents-Be1Yhekx.js";import"./contracts.generated-BRyBcIRY.js";import"./index-DET2Pbf7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d5568c8c-1d21-4381-b868-03578c6a487a",o._sentryDebugIdIdentifier="sentry-dbid-d5568c8c-1d21-4381-b868-03578c6a487a")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,u)=>(m(),a(n,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-KhOt-yb9.js.map
