import{conf as i,language as e}from"./typescript-DenkHrFQ.js";import"./editor.main-Cl_NziBX.js";import"./jwt-decode.esm-BAedLjyW.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="a3d8a6a2-8bd8-4c65-80db-d59cec1b78f9",t._sentryDebugIdIdentifier="sentry-dbid-a3d8a6a2-8bd8-4c65-80db-d59cec1b78f9")}catch{}})();var a=i,c={defaultToken:"invalid",tokenPostfix:".js",keywords:["break","case","catch","class","continue","const","constructor","debugger","default","delete","do","else","export","extends","false","finally","for","from","function","get","if","import","in","instanceof","let","new","null","return","set","super","switch","symbol","this","throw","true","try","typeof","undefined","var","void","while","with","yield","async","await","of"],typeKeywords:[],operators:e.operators,symbols:e.symbols,escapes:e.escapes,digits:e.digits,octaldigits:e.octaldigits,binarydigits:e.binarydigits,hexdigits:e.hexdigits,regexpctl:e.regexpctl,regexpesc:e.regexpesc,tokenizer:e.tokenizer};export{a as conf,c as language};
//# sourceMappingURL=javascript-bZccXmkr.js.map
